@@ -412,7 +412,8 @@ class BaseJAAQLController:
 
                         if not do_allow_all and ret_status != HTTPStatus.UNAUTHORIZED and ret_status !=\
                                 HTTPStatus.NOT_IMPLEMENTED and ret_status != HTTPStatus.BAD_REQUEST and \
-                                ret_status != HTTPStatus.UNPROCESSABLE_ENTITY:
+                                ret_status != HTTPStatus.UNPROCESSABLE_ENTITY and \
+                                ret_status != CustomHTTPStatus.DATABASE_NO_EXIST:
                             try:
                                 self.get_response(method, ret_status)
                             except Exception as sub_ex:
@@ -424,6 +425,9 @@ class BaseJAAQLController:
 
                         throw_ex = ex
 
+                    if jaaql_connection is not None:
+                        jaaql_connection.pg_pool.closeall()
+
                     duration = round((datetime.now() - start_time).total_seconds() * 1000)
                     if user_id is not None:
                         self.model.log(user_id, start_time, duration, ex_msg, method_input, ip_id, ua_id, ret_status,
